
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output indent="yes"/>

	<xsl:variable name="TimeStamp">
		<xsl:value-of select="format-dateTime(current-dateTime(),'[Y0001][M01][D01]-[H01][m01][s][f]')"/>
	</xsl:variable>

	<xsl:variable name="Date">
		<xsl:value-of select="substring-before(Orders/Order/OrderDate,' ')"/>
	</xsl:variable>

	<xsl:variable name="Time">
		<xsl:value-of select="substring-after(Orders/Order/OrderDate,' ')"/>
	</xsl:variable>

	<xsl:variable name="UserID">
		<xsl:choose>
			<xsl:when test="Orders/Order/BillingEmail !=''">
				<xsl:value-of select="substring-before(Orders/Order/BillingEmail,'@')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'NoID'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="JobsList" select="string-join(Orders/Order/OrderLineItems/OrderLineItem/Line_Id, ',')"/>

	<xsl:template match="Order">
		<Order>
			<JDF Category="DigitalPrinting" ID="Order-{OrderNumber}" JobID="{$TimeStamp}-{generate-id()}" JobPartID="jdfPart1" SettingsPolicy="MustHonor" Status="Waiting" Type="ProcessGroup"
			     Types="LayoutPreparation DigitalPrinting HoleMaking WireCombBinding" Version="1.3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://www.CIP4.org/JDFSchema_1_1">
				<Comment Name="oce:JobList">
					<xsl:value-of select="$JobsList"/>
				</Comment>
				<ResourcePool>
					<NodeInfo ID="rNodeInfo1" Class="Parameter" Status="Available"/>
					<Contact Class="Parameter" ContactTypes="Customer" ID="rContactID" Status="Available" UserID="{$UserID}">
						<Company OrganizationName="{/Orders/Order/BillingCompany}">
							<OrganizationalUnit/>
						</Company>
						<Person FamilyName="{/Orders/Order/BillingLastName}" FirstName="{/Orders/Order/BillingFirstName}"/>
						<ComChannel ChannelType="Phone" Locator="{/Orders/Order/BillingPhone}"/>
						<ComChannel ChannelType="Email" Locator="{/Orders/Order/BillingEmail}"/>
					</Contact>
					<Contact Class="Parameter" ContactTypes="Delivery" ID="rDeliveryID" Status="Available">
						<Person FamilyName="{/Orders/Order/ShippingLastName}" FirstName="{/Orders/Order/ShippingFirstName}"/>
						<Address City="{/Orders/Order/ShippingCity}" Country="{/Orders/Order/ShippingCountry}" PostalCode="{/Orders/Order/ShippingPostcode}" Street="{/Orders/Order/ShippingAddress}"/>
					</Contact>
					<CustomerInfo BillingCode="12345" Class="Parameter" CustomerID="CustomerID" CustomerJobName="{Orders/Order/OrderNumber}" ID="rCustomerInfo1" Status="Available">
						<ContactRef rRef="rContactID"/>
					</CustomerInfo>
					<DeliveryParams Class="Parameter" ID="rDeliveryInfo" Method="ExpressMail" Status="Available">
						<ContactRef rRef="rDeliveryID"/>
					</DeliveryParams>
				</ResourcePool>
				<ResourceLinkPool>
					<CustomerInfoLink rRef="rCustomerInfo1" Usage="Input"/>
					<NodeInfoLink rRef="rNodeInfo1" Usage="Input"/>
					<RunListLink rRef="rRunList1" Usage="Input"/>
				</ResourceLinkPool>
			</JDF>
		</Order>
		<xsl:for-each select="OrderLineItems/OrderLineItem">
			<Job>
				<JDF Category="DigitalPrinting" ID="{Line_Id}" JobID="{$TimeStamp}-{generate-id()}" JobPartID="jdfPart1" SettingsPolicy="MustHonor" Status="Waiting" Type="ProcessGroup" Types="LayoutPreparation DigitalPrinting HoleMaking WireCombBinding"
				     Version="1.3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns="http://www.CIP4.org/JDFSchema_1_1">
					<ResourcePool>
						<NodeInfo ID="rNodeInfo1" Class="Parameter" Status="Available">
							<GeneralID IDUsage="ProductName" IDValue="{Name}"/>
						</NodeInfo>
						<RunList ID="rRunList1" Status="Available" Class="Parameter">
							<LayoutElementRef rRef="rLayoutElementID"/>
						</RunList>
						<Media ID="rMedia1" Class="Consumable" Status="Available" DescriptiveName="A4 White 80grs"/>
						<LayoutElement ID="rLayoutElementID" Status="Available" Class="Parameter">
							<FileSpec UserFileName="{Name}.pdf" URL="{Link}" MimeType="application/pdf"/>
						</LayoutElement>
						<LayoutPreparationParams ID="rLayoutPreparationParams1" Class="Parameter" Status="Available" Sides="TwoSidedFlipY"/>
						<RenderingParams ID="rRenderingParams1" Class="Parameter" Status="Available"/>
						<DigitalPrintingParams ID="rDigitalPrintingParams1" Class="Parameter" Status="Available" PartIDKeys="RunIndex" Collate="SheetSetAndJob" OutputBin="AutoSelect">
							<MediaRef rRef="rMedia1"/>
						</DigitalPrintingParams>
						<ColorantControl ID="CCID" Class="Parameter" Status="Available" ProcessColorModel="DeviceCMYK" SettingsPolicy="MustHonor"/>
						<Component ID="rComponentFinalProduct" Status="Unavailable" Class="Quantity" ComponentType="FinalProduct"/>
					</ResourcePool>
					<ResourceLinkPool>
						<NodeInfoLink rRef="rNodeInfo1" Usage="Input"/>
						<RunListLink rRef="rRunList1" Usage="Input"/>
						<MediaLink rRef="rMedia1" Usage="Input"/>
						<LayoutPreparationParamsLink rRef="rLayoutPreparationParams1" Usage="Input"/>
						<RenderingParamsLink rRef="rRenderingParams1" Usage="Input"/>
						<DigitalPrintingParamsLink rRef="rDigitalPrintingParams1" Usage="Input"/>
						<ColorantControlLink rRef="CCID" Usage="Input"/>
						<ComponentLink rRef="rComponentFinalProduct" Usage="Output" Amount="{Copies}"/>
					</ResourceLinkPool>
				</JDF>
			</Job>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>